@@ -1,7 +1,7 @@
 package HTTP::Tiny::Cache_CustomRetry;
 
 our $DATE = '2019-04-12'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use warnings;
@@ -27,7 +27,7 @@ HTTP::Tiny::Cache_CustomRetry - Cache response + retry failed request
 
 =head1 VERSION
 
-This document describes version 0.002 of HTTP::Tiny::Cache_CustomRetry (from Perl distribution HTTP-Tiny-Cache_CustomRetry), released on 2019-04-12.
+This document describes version 0.003 of HTTP::Tiny::Cache_CustomRetry (from Perl distribution HTTP-Tiny-Cache_CustomRetry), released on 2019-04-12.
 
 =head1 SYNOPSIS
 
@@ -43,7 +43,8 @@ HT:CustomRetry both extend L<HTTP::Tiny> (HT), this module modifies
 HT:CustomRetry's C<@ISA> to point to HT:Retry instead. This is a hack and
 probably only serves to show the limitation of subclassing mechanism for adding
 functionalities, like we see in the L<WWW::Mechanize> land. For an alternative
-solution, see L<HTTP::Huge> which is a plugin-enabled variant of HTTP::Tiny.
+solution, see L<HTTP::Tiny::Plugin> which is a plugin-enabled variant of
+HTTP::Tiny.
 
 =head1 HOMEPAGE
 
@@ -65,7 +66,7 @@ feature.
 
 L<HTTP::Tiny::Cache>, L<HTTP::Tiny::CustomRetry>
 
-L<HTTP::Huge>
+L<HTTP::Tiny::Plugin>
 
 L<HTTP::Tiny>
 
